<?php

/**
 * This is the model class for table "{{tag}}".
 *
 * The followings are the available columns in table '{{tag}}':
 * @property integer $id
 * @property string $name
 * @property integer $frequency
 */
class Tag extends CActiveRecord
{
	/**
	 * Returns the static model of the specified AR class.
	 * @param string $className active record class name.
	 * @return Tag the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}

	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return '{{tag}}';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('name', 'required'),
			array('frequency', 'numerical', 'integerOnly'=>true),
			array('name', 'length', 'max'=>50),
			// The following rule is used by search().
			// Please remove those attributes that should not be searched.
			array('id, name, frequency', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'id' => 'ID',
			'name' => 'Name',
			'frequency' => 'Frequency',
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 * @return CActiveDataProvider the data provider that can return the models based on the search/filter conditions.
	 */
	public function search()
	{
		// Warning: Please modify the following code to remove attributes that
		// should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('id',$this->id);
		$criteria->compare('name',$this->name,true);
		$criteria->compare('frequency',$this->frequency);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
		));
	}
        
//        array preg_split ( string pattern, string subject [, int limit [, int flags]] )
//        返回一个数组，包含 subject 中沿着与 pattern 匹配的边界所分割的子串。 
//        如果指定了 limit，则最多返回 limit 个子串，如果 limit 是 -1，则意味着没有限制，可以用来继续指定可选参数 flags。 
//        此处方法意为：用，分割字符串‘，’前后如果存在空白字符一并划入分割符。
        public static function string2array($tags){
            return preg_split('/\s*,\s*/', trim($tags),-1, PREG_SPLIT_NO_EMPTY);
        } 
        
        public static function array2string($tags){
            return implode(',', $tags);
        }
        
        public function updateFrequency($oldTags, $newTags){
            $oldTags = self::string2array($oldTags);
            $newTags = self::string2array($newTags);
            $this->addTags(array_values(array_diff($newTags, $oldTags)));
            $this->removeTags(array_values(array_diff($oldTags, $newTags)));
        }
        
        public function addTags($tags){
            $criteria = new CDbCriteria();
            $criteria->addInCondition('name', $tags);
            $this->updateCounters(array('frequency' => 1), $criteria);
            foreach ($tags as $name) {
                if(!$this->exists('name=:name', array(':name' => $name))){
                    $tag = new Tag();
                    $tag->name = $name;
                    $tag->frequency = 1;
                    $tag->save();
                }
            }
        }
        
        public function removeTags($tags){
            if(empty($tags))
                return ;
            $criteria = new CDbCriteria();
            $criteria->addInCondition('name', $tags);
            $this->updateCounters(array('frequency' => -1), $criteria);
            $this->deleteAll('frequency<=0');
        }
        
        public function findTagWeights($limit = 20){
            $models = $this->findAll(array(
                'order' => 'frequency DESC',
                'limit' => $limit,
            ));
            $total = 0;
            foreach($models as $model){
                $total += $model->frequency;
            }
            $tags = array();
            if($total > 0){
                foreach ($models as $model) {
                    $tags[$model->name] = 8+(int)(16*$model->frequency/($total+10));
                }
                ksort($tags);
            }
            return $tags;
        }
}